# python-weka-wrapper3

Python wrapper for the Java machine learning workbench [Weka](http://www.cs.waikato.ac.nz/~ml/weka/)
using the [javabridge](https://pypi.python.org/pypi/javabridge) library.

Requirements:

* Python 3 (for Python 2.7 version see [here](https://github.com/fracpete/python-weka-wrapper))
  * javabridge (>= 1.0.14)
  * matplotlib (optional)
  * pygraphviz (optional)
  * PIL (optional)
* Oracle JDK 1.8+

Uses:
* Weka (3.9.5)

## Installation

Detailed instructions and links to videos on installing the library are located
[here](http://fracpete.github.io/python-weka-wrapper3/install.html).

Please note, that you need a build environment to compile some libraries from source.

## Forum

You can post questions, patches or enhancement requests in the following Google Group:

https://groups.google.com/forum/#!forum/python-weka-wrapper

## Examples
See [python-weka-wrapper-examples3](https://github.com/fracpete/python-weka-wrapper3-examples)
repository for example code on the various APIs. Also, check out the sphinx
documentation in the **doc** directory. You can generate HTML documentation
using the `make html` command in the **doc** directory.

Available online documentation:
* [Full documentation](http://fracpete.github.io/python-weka-wrapper3/)
* Shortcuts
  * [Command-line](http://fracpete.github.io/python-weka-wrapper3/commandline.html)
  * [API](http://fracpete.github.io/python-weka-wrapper3/api.html)
  * [Examples](http://fracpete.github.io/python-weka-wrapper3/examples.html)

## Download statistics
For viewing recent download statistics, go to [pypistats](https://pypistats.org//api/packages/python-weka-wrapper3/recent).
